@@ -8,8 +8,7 @@ class Plotly:
 
     __css_base = ".modebar {display: none;} \n.modebar-container {display: none;} "
 
-    def export(self, chart, filename, css=None):
-        """ create html export and add css to it"""
+    def __export(self, chart, filename, css=None):
         html_filename = f"{filename.split('.')[0]}.html"
         html_exist = os.path.exists(html_filename)
         chart.write_html(html_filename)
@@ -51,6 +50,14 @@ class Plotly:
             return
         print("Save as", filename)
 
+    def export(self, chart, filenames, css=None):
+        """ create html export and add css to it"""
+        if isinstance(filenames, list):
+            for filename in filenames:
+                self.__export(chart, filename, css)
+        else:
+            self.__export(chart, filenames, css)
+
     def __predict(self, stock, visible):
         charts = []
         if "ARIMA" in stock.columns:
@@ -153,6 +160,55 @@ class Plotly:
                 )
             return charts
 
+    def linechart(dataset, label_x: str, label_y: list):
+        charts = []
+        layout = dict(
+            dragmode="pan",
+            xaxis_rangeslider_visible=False,
+            showlegend=False,
+            updatemenus=[],
+        )
+        for i in range(len(label_y)):
+            filter_col = label_y[i]
+            charts.append(
+                go.Scatter(
+                    x=dataset[label_x],
+                    y=dataset[filter_col],
+                    name=filter_col,
+                )
+            )
+        fig = go.Figure(data=charts, layout=layout)
+        fig.show()
+        return fig
+
+    def candlestick(
+        dataset,
+        label_x: str,
+        label_open: str,
+        label_high: str,
+        label_low: str,
+        label_close: str,
+    ):
+        charts = []
+        layout = dict(
+            dragmode="pan",
+            xaxis_rangeslider_visible=False,
+            showlegend=False,
+            updatemenus=[],
+        )
+        charts = [
+            go.Candlestick(
+                x=dataset[label_x],
+                open=dataset[label_open],
+                high=dataset[label_high],
+                low=dataset[label_low],
+                close=dataset[label_close],
+            )
+        ]
+        fig = go.Figure(data=charts, layout=layout)
+        fig.show()
+        return fig
+
     def stock(
         self,
         stock_data,
@@ -162,7 +218,11 @@ class Plotly:
         filter_all=False,
     ):
         """ generate financial_chart """
-        stock_companies = stock_data.Company.unique()
+        stock_data_copy = stock_data.copy()
+        stock_companies = stock_data_copy.Company.unique()
+        if len(stock_companies) == 0:
+            stock_data["Company"] = "Company_1"
+            stock_companies = stock_data_copy.Company.unique()
         data = []
         buttons = []
         if filter_all:
@@ -175,7 +235,7 @@ class Plotly:
             )
         for y in range(len(stock_companies)):
             company = stock_companies[y]
-            stock = stock_data.loc[stock_data["Company"] == company]
+            stock = stock_data_copy.loc[stock_data_copy["Company"] == company]
             charts = []
             visible = filter_all if filter_all else y == 0
             charts.extend(self.__moving_average(stock, visible))
@@ -252,6 +312,7 @@ class Plotly:
                     )
                 ],
             )
+        fig.show()
         return fig
 
     def table(self, header_values, cells_values, header_color="rgb(136,233,175)"):
